NAME

DateTime::Locale::fi_FI

SYNOPSIS

use DateTime;

my $dt = DateTime->now( locale => 'fi_FI' );
print $dt->month_name();

DESCRIPTION

This is the DateTime locale package for Finnish Finland.

DATA

This locale inherits from the DateTime::Locale::fi locale.

It contains the following data.

Days

Wide (format)

maanantaina
tiistaina
keskiviikkona
torstaina
perjantaina
lauantaina
sunnuntaina

Abbreviated (format)

ma
ti
ke
to
pe
la
su

Narrow (format)

M
T
K
T
P
L
S

Wide (stand-alone)

maanantaina
tiistaina
keskiviikkona
torstaina
perjantaina
lauantaina
sunnuntaina

Abbreviated (stand-alone)

ma
ti
ke
to
pe
la
su

Narrow (stand-alone)

M
T
K
T
P
L
S

Months

Wide (format)

tammikuuta
helmikuuta
maaliskuuta
huhtikuuta
toukokuuta
kesäkuuta
heinäkuuta
elokuuta
syyskuuta
lokakuuta
marraskuuta
joulukuuta

Abbreviated (format)

tammi
helmi
maalis
huhti
touko
kesä
heinä
elo
syys
loka
marras
joulu

Narrow (format)

T
H
M
H
T
K
H
E
S
L
M
J

Wide (stand-alone)

tammikuuta
helmikuuta
maaliskuuta
huhtikuuta
toukokuuta
kesäkuuta
heinäkuuta
elokuuta
syyskuuta
lokakuuta
marraskuuta
joulukuuta

Abbreviated (stand-alone)

tammi
helmi
maalis
huhti
touko
kesä
heinä
elo
syys
loka
marras
joulu

Narrow (stand-alone)

T
H
M
H
T
K
H
E
S
L
M
J

Quarters

Wide (format)

1. neljännes
2. neljännes
3. neljännes
4. neljännes

Abbreviated (format)

1. nelj.
2. nelj.
3. nelj.
4. nelj.

Narrow (format)

1
2
3
4

Wide (stand-alone)

1. neljännes
2. neljännes
3. neljännes
4. neljännes

Abbreviated (stand-alone)

1. nelj.
2. nelj.
3. nelj.
4. nelj.

Narrow (stand-alone)

1
2
3
4

Eras

Wide

ennen Kristuksen syntymää
jälkeen Kristuksen syntymän

Abbreviated

eKr.
jKr.

Narrow

eKr.
jKr.

Date Formats

Full

 2008-02-05T12:30:30 = tiistaina 5. helmikuuta 2008
 1995-12-22T09:05:02 = perjantaina 22. joulukuuta 1995
-0010-09-15T04:44:23 = lauantaina 15. syyskuuta -010

Long

 2008-02-05T12:30:30 = 5. helmikuuta 2008
 1995-12-22T09:05:02 = 22. joulukuuta 1995
-0010-09-15T04:44:23 = 15. syyskuuta -010

Medium

 2008-02-05T12:30:30 = 5.2.2008
 1995-12-22T09:05:02 = 22.12.1995
-0010-09-15T04:44:23 = 15.9.-010

Short

 2008-02-05T12:30:30 = 5.2.2008
 1995-12-22T09:05:02 = 22.12.1995
-0010-09-15T04:44:23 = 15.9.-010

Default

 2008-02-05T12:30:30 = 5.2.2008
 1995-12-22T09:05:02 = 22.12.1995
-0010-09-15T04:44:23 = 15.9.-010

Time Formats

Full

 2008-02-05T12:30:30 = 12.30.30 UTC
 1995-12-22T09:05:02 = 9.05.02 UTC
-0010-09-15T04:44:23 = 4.44.23 UTC

Long

 2008-02-05T12:30:30 = 12.30.30 UTC
 1995-12-22T09:05:02 = 9.05.02 UTC
-0010-09-15T04:44:23 = 4.44.23 UTC

Medium

 2008-02-05T12:30:30 = 12.30.30
 1995-12-22T09:05:02 = 9.05.02
-0010-09-15T04:44:23 = 4.44.23

Short

 2008-02-05T12:30:30 = 12.30
 1995-12-22T09:05:02 = 9.05
-0010-09-15T04:44:23 = 4.44

Default

 2008-02-05T12:30:30 = 12.30.30
 1995-12-22T09:05:02 = 9.05.02
-0010-09-15T04:44:23 = 4.44.23

Datetime Formats

Full

 2008-02-05T12:30:30 = tiistaina 5. helmikuuta 2008 12.30.30 UTC
 1995-12-22T09:05:02 = perjantaina 22. joulukuuta 1995 9.05.02 UTC
-0010-09-15T04:44:23 = lauantaina 15. syyskuuta -010 4.44.23 UTC

Long

 2008-02-05T12:30:30 = 5. helmikuuta 2008 12.30.30 UTC
 1995-12-22T09:05:02 = 22. joulukuuta 1995 9.05.02 UTC
-0010-09-15T04:44:23 = 15. syyskuuta -010 4.44.23 UTC

Medium

 2008-02-05T12:30:30 = 5.2.2008 12.30.30
 1995-12-22T09:05:02 = 22.12.1995 9.05.02
-0010-09-15T04:44:23 = 15.9.-010 4.44.23

Short

 2008-02-05T12:30:30 = 5.2.2008 12.30
 1995-12-22T09:05:02 = 22.12.1995 9.05
-0010-09-15T04:44:23 = 15.9.-010 4.44

Default

 2008-02-05T12:30:30 = 5.2.2008 12.30.30
 1995-12-22T09:05:02 = 22.12.1995 9.05.02
-0010-09-15T04:44:23 = 15.9.-010 4.44.23

Available Formats

HHmm (HH.mm)

 2008-02-05T12:30:30 = 12.30
 1995-12-22T09:05:02 = 09.05
-0010-09-15T04:44:23 = 04.44

HHmmss (HH.mm.ss)

 2008-02-05T12:30:30 = 12.30.30
 1995-12-22T09:05:02 = 09.05.02
-0010-09-15T04:44:23 = 04.44.23

Hm (H.mm)

 2008-02-05T12:30:30 = 12.30
 1995-12-22T09:05:02 = 9.05
-0010-09-15T04:44:23 = 4.44

M (L)

 2008-02-05T12:30:30 = 2
 1995-12-22T09:05:02 = 12
-0010-09-15T04:44:23 = 9

MEd (E d.M.)

 2008-02-05T12:30:30 = ti 5.2.
 1995-12-22T09:05:02 = pe 22.12.
-0010-09-15T04:44:23 = la 15.9.

MMM (LLL)

 2008-02-05T12:30:30 = helmi
 1995-12-22T09:05:02 = joulu
-0010-09-15T04:44:23 = syys

MMMEd (E d. MMM)

 2008-02-05T12:30:30 = ti 5. helmi
 1995-12-22T09:05:02 = pe 22. joulu
-0010-09-15T04:44:23 = la 15. syys

MMMMEd (E d. MMMM)

 2008-02-05T12:30:30 = ti 5. helmikuuta
 1995-12-22T09:05:02 = pe 22. joulukuuta
-0010-09-15T04:44:23 = la 15. syyskuuta

MMMMd (d. MMMM)

 2008-02-05T12:30:30 = 5. helmikuuta
 1995-12-22T09:05:02 = 22. joulukuuta
-0010-09-15T04:44:23 = 15. syyskuuta

MMMd (d. MMM)

 2008-02-05T12:30:30 = 5. helmi
 1995-12-22T09:05:02 = 22. joulu
-0010-09-15T04:44:23 = 15. syys

Md (d.M.)

 2008-02-05T12:30:30 = 5.2.
 1995-12-22T09:05:02 = 22.12.
-0010-09-15T04:44:23 = 15.9.

d (d)

 2008-02-05T12:30:30 = 5
 1995-12-22T09:05:02 = 22
-0010-09-15T04:44:23 = 15

mmss (mm.ss)

 2008-02-05T12:30:30 = 30.30
 1995-12-22T09:05:02 = 05.02
-0010-09-15T04:44:23 = 44.23

ms (mm.ss)

 2008-02-05T12:30:30 = 30.30
 1995-12-22T09:05:02 = 05.02
-0010-09-15T04:44:23 = 44.23

y (yyyy)

 2008-02-05T12:30:30 = 2008
 1995-12-22T09:05:02 = 1995
-0010-09-15T04:44:23 = -010

yM (L.yyyy)

 2008-02-05T12:30:30 = 2.2008
 1995-12-22T09:05:02 = 12.1995
-0010-09-15T04:44:23 = 9.-010

yMEd (EEE d.M.yyyy)

 2008-02-05T12:30:30 = ti 5.2.2008
 1995-12-22T09:05:02 = pe 22.12.1995
-0010-09-15T04:44:23 = la 15.9.-010

yMMM (LLL yyyy)

 2008-02-05T12:30:30 = helmi 2008
 1995-12-22T09:05:02 = joulu 1995
-0010-09-15T04:44:23 = syys -010

yMMMEd (EEE d. MMM yyyy)

 2008-02-05T12:30:30 = ti 5. helmi 2008
 1995-12-22T09:05:02 = pe 22. joulu 1995
-0010-09-15T04:44:23 = la 15. syys -010

yMMMM (LLLL yyyy)

 2008-02-05T12:30:30 = helmikuuta 2008
 1995-12-22T09:05:02 = joulukuuta 1995
-0010-09-15T04:44:23 = syyskuuta -010

yQ (Q/yyyy)

 2008-02-05T12:30:30 = 1/2008
 1995-12-22T09:05:02 = 4/1995
-0010-09-15T04:44:23 = 3/-010

yQQQ (QQQ yyyy)

 2008-02-05T12:30:30 = 1. nelj. 2008
 1995-12-22T09:05:02 = 4. nelj. 1995
-0010-09-15T04:44:23 = 3. nelj. -010

yyMM (M/yy)

 2008-02-05T12:30:30 = 2/8
 1995-12-22T09:05:02 = 12/95
-0010-09-15T04:44:23 = 9/10

yyMMM (MMM yy)

 2008-02-05T12:30:30 = helmi 8
 1995-12-22T09:05:02 = joulu 95
-0010-09-15T04:44:23 = syys 10

yyQ (Q/yy)

 2008-02-05T12:30:30 = 1/8
 1995-12-22T09:05:02 = 4/95
-0010-09-15T04:44:23 = 3/10

yyyyM (M/yyyy)

 2008-02-05T12:30:30 = 2/2008
 1995-12-22T09:05:02 = 12/1995
-0010-09-15T04:44:23 = 9/-010

yyyyMEEEd (EEE d.M.yyyy)

 2008-02-05T12:30:30 = ti 5.2.2008
 1995-12-22T09:05:02 = pe 22.12.1995
-0010-09-15T04:44:23 = la 15.9.-010

yyyyMMMM (LLLL yyyy)

 2008-02-05T12:30:30 = helmikuuta 2008
 1995-12-22T09:05:02 = joulukuuta 1995
-0010-09-15T04:44:23 = syyskuuta -010

yyyyQQQQ (QQQQ yyyy)

 2008-02-05T12:30:30 = 1. neljännes 2008
 1995-12-22T09:05:02 = 4. neljännes 1995
-0010-09-15T04:44:23 = 3. neljännes -010

Miscellaneous

Prefers 24 hour time?

Yes

Local first day of the week

maanantaina

SUPPORT

See DateTime::Locale.

AUTHOR

Dave Rolsky <autarch@urth.org>

COPYRIGHT

Copyright (c) 2008 David Rolsky. All rights reserved. This program is free software; you can redistribute it and/or modify it under the same terms as Perl itself.

This module was generated from data provided by the CLDR project, see the LICENSE.cldr in this distribution for details on the CLDR data's license.